Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(185)

Unified Diff: content/browser/android/synchronous_compositor_host.cc

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: rebase Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/android/synchronous_compositor_host.cc
diff --git a/content/browser/android/synchronous_compositor_host.cc b/content/browser/android/synchronous_compositor_host.cc
index 181a5addd12905ca1d1694d09713775df847a5cf..62fb6599795b9a9d06e23438022e67b9a8b412bf 100644
--- a/content/browser/android/synchronous_compositor_host.cc
+++ b/content/browser/android/synchronous_compositor_host.cc
@@ -88,8 +88,8 @@ SynchronousCompositorHost::~SynchronousCompositorHost() {
bool SynchronousCompositorHost::OnMessageReceived(const IPC::Message& message) {
bool handled = true;
IPC_BEGIN_MESSAGE_MAP(SynchronousCompositorHost, message)
- IPC_MESSAGE_HANDLER(SyncCompositorHostMsg_OutputSurfaceCreated,
- OutputSurfaceCreated)
+ IPC_MESSAGE_HANDLER(SyncCompositorHostMsg_CompositorFrameSinkCreated,
+ CompositorFrameSinkCreated)
IPC_MESSAGE_HANDLER(SyncCompositorHostMsg_UpdateState, ProcessCommonParams)
IPC_MESSAGE_HANDLER_GENERIC(SyncCompositorHostMsg_ReturnFrame,
DemandDrawHwReceiveFrame(message))
@@ -379,8 +379,8 @@ void SynchronousCompositorHost::DidSendBeginFrame(
rph_observer_->SyncStateAfterVSync(window_android, this);
}
-void SynchronousCompositorHost::OutputSurfaceCreated() {
- // New output surface is not aware of state from Browser side. So need to
+void SynchronousCompositorHost::CompositorFrameSinkCreated() {
+ // New CompositorFrameSink is not aware of state from Browser side. So need to
// re-send all browser side state here.
sender_->Send(
new SyncCompositorMsg_SetMemoryPolicy(routing_id_, bytes_limit_));

Powered by Google App Engine
This is Rietveld 408576698